==> openshift-model-monitoring-4.11.1-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/NamespaceSelectorFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface NamespaceSelectorFluent<A extends NamespaceSelectorFluent<A>> extends Fluent<A>{


    public Boolean isAny();
    public A withAny(Boolean any);
    public Boolean hasAny();
    public A withNewAny(String arg1);
    public A withNewAny(boolean arg1);
    public A addToMatchNames(int index,String item);
    public A setToMatchNames(int index,String item);
    public A addToMatchNames(String... items);
    public A addAllToMatchNames(Collection<String> items);
    public A removeFromMatchNames(String... items);
    public A removeAllFromMatchNames(Collection<String> items);
    public List<String> getMatchNames();
    public String getMatchName(int index);
    public String getFirstMatchName();
    public String getLastMatchName();
    public String getMatchingMatchName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingMatchName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withMatchNames(List<String> matchNames);
    public A withMatchNames(String... matchNames);
    public Boolean hasMatchNames();
    public A addNewMatchName(String arg1);
    public A addNewMatchName(StringBuilder arg1);
    public A addNewMatchName(StringBuffer arg1);



}

==> openshift-model-monitoring-5.1.1-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/NamespaceSelectorFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface NamespaceSelectorFluent<A extends NamespaceSelectorFluent<A>> extends Fluent<A> {


    public Boolean isAny();
    public A withAny(Boolean any);
    public Boolean hasAny();
    public A withNewAny(String arg1);
    public A withNewAny(boolean arg1);
    public A addToMatchNames(int index,String item);
    public A setToMatchNames(int index,String item);
    public A addToMatchNames(String... items);
    public A addAllToMatchNames(Collection<String> items);
    public A removeFromMatchNames(String... items);
    public A removeAllFromMatchNames(Collection<String> items);
    public List<String> getMatchNames();
    public String getMatchName(int index);
    public String getFirstMatchName();
    public String getLastMatchName();
    public String getMatchingMatchName(Predicate<String> predicate);
    public Boolean hasMatchingMatchName(Predicate<String> predicate);
    public A withMatchNames(List<String> matchNames);
    public A withMatchNames(String... matchNames);
    public Boolean hasMatchNames();
    public A addNewMatchName(String arg1);
    public A addNewMatchName(StringBuilder arg1);
    public A addNewMatchName(StringBuffer arg1);
}
